@@ -99,28 +99,28 @@ class NetworkSettings(GraphSettings):
         super().__init__(edges=edges, hiddenDeviceTypes=['ap', 'fex', 'host', 'phone'])
 
     @staticmethod
-    def _update_edge(children: List[EdgeSettings], name: str, attribute: str):
+    def _update_edge(children: List[EdgeSettings], name: str, attribute: str, bool_value=False):
         for edge in children:
             if edge.name.lower() == name:
-                setattr(edge, attribute, False)
+                setattr(edge, attribute, bool_value)
                 return True
         return False
 
-    def _update_group(self, name: str, attribute: str, group: bool = False):
+    def _update_group(self, name: str, attribute: str, group: bool = False, bool_value=False):
         for edge in self.edges:
             if group and isinstance(edge, GroupSettings) and edge.name.lower() == name:
-                setattr(edge, attribute, False)
+                setattr(edge, attribute, bool_value)
                 return True
             elif not group:
-                if isinstance(edge, GroupSettings) and self._update_edge(edge.children, name, attribute):
+                if isinstance(edge, GroupSettings) and self._update_edge(edge.children, name, attribute, bool_value):
                     return self._update_group(edge.name.lower(), 'grouped', True)
-                elif isinstance(edge, EdgeSettings) and self._update_edge([edge], name, attribute):
+                elif isinstance(edge, EdgeSettings) and self._update_edge([edge], name, attribute, bool_value):
                     return True
         return False
 
-    def hide_protocol(self, protocol_name: str):
+    def hide_protocol(self, protocol_name: str, unhide: bool = False):
         if protocol_name.lower() in VALID_NET_PROTOCOLS:
-            return self._update_group(protocol_name.lower(), attribute='visible', group=False)
+            return self._update_group(protocol_name.lower(), attribute='visible', group=False, bool_value=unhide)
         else:
             raise KeyError(f"Protocol {protocol_name} does not exist.  Valid protocols are {VALID_NET_PROTOCOLS}")
 
